import { select, csv } from 'd3';
import { scatterPlot } from './scatterPlot';

const width = window.innerWidth;
const height = window.innerHeight;

const margin = {
  top: 20,
  right: 40,
  bottom: 70,
  left: 70,
};

const csvUrl = [
  'https://gist.githubusercontent.com/',
  'curran/', // User
  'a08a1080b88344b0c8a7/', // Id of the Gist
  'raw/0e7a9b0a5d22642a06d3d5b9bcbad9890c8ee534/', // commit
  'iris.csv', // File name
].join('');

const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;

  return d;
};

const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const columns = data.columns;
  
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(data)
    .xValue((d) => d[columns[0]])
    .xAxisTitle(columns[0])
    .yValue((d) => d[columns[1]])
    .yAxisTitle(columns[1])
    .margin(margin)
    .radius(5);

  svg.call(plot);
};

main();
