import {
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
} from 'd3';

export const scatterPlot = () => {
  let width;
  let height;
  let margin;
  let data;
  let radius;
  let xValue;
  let yValue;
  let xAxisTitle;
  let yAxisTitle;

  const my = (selection) => {
    const x = scaleLinear()
      .domain(extent(data, xValue))
      .range([margin.left, width - margin.right]);

    const y = scaleLinear()
      .domain(extent(data, yValue))
      .range([height - margin.bottom, margin.top]);

    const marks = data.map((d) => ({
      x: x(xValue(d)),
      y: y(yValue(d)),
    }));

    const xAxis = axisBottom().scale(x);
    const yAxis = axisLeft().scale(y);

    console.log(xValue);

    selection
      .selectAll('circle')
      .data(marks)
      .join('circle')
      .attr('cx', (d) => d.x)
      .attr('cy', (d) => d.y)
      .attr('r', radius);

    selection
      .append('g')
      .attr(
        'transform',
        `translate(0, ${height - margin.bottom})`
      )
      .call(xAxis);

    selection
      .append('g')
      .attr('transform', `translate(${margin.left}, 0)`)
      .call(yAxis);

    selection
      .append('text')
      .attr('class', 'axis-title')
      .text(xAxisTitle)
      .attr('x', width / 2)
      .attr('y', height - margin.bottom)
      .attr('dy', '2.5em')
      .attr('text-anchor', 'middle');

    selection
      .append('text')
      .attr('class', 'axis-title')
      .text(yAxisTitle)
      .attr('transform', 'rotate(-90)')
      .attr('y', 0)
      .attr('x', -height / 2)
      .attr('dy', '1em');
  };

  // Getters and setters
  my.width = function (_) {
    return arguments.length ? ((width = _), my) : width;
  };

  my.height = function (_) {
    return arguments.length ? ((height = _), my) : height;
  };

  my.margin = function (_) {
    return arguments.length ? ((margin = _), my) : margin;
  };

  my.data = function (_) {
    return arguments.length ? ((data = _), my) : data;
  };

  my.radius = function (_) {
    return arguments.length ? ((radius = _), my) : radius;
  };

  my.xValue = function (_) {
    return arguments.length ? ((xValue = _), my) : xValue;
  };

  my.yValue = function (_) {
    return arguments.length ? ((yValue = _), my) : yValue;
  };

  my.xAxisTitle = function (_) {
    return arguments.length
      ? ((xAxisTitle = _), my)
      : xAxisTitle;
  };
  
    my.yAxisTitle = function (_) {
    return arguments.length
      ? ((yAxisTitle = _), my)
      : yAxisTitle;
  };

  return my;
};
